import json
import os


class lang:
    def __init__(self):
        file = open("lang")
        ld = file.read()
        file.close()
        file = open("lang.json")
        self.lang_list = json.load(file)
        file.close()

        self.enable_lang = self.lang_list[ld]
        path = "./plugins/"
        files = os.listdir(path)
        files_dir = [f for f in files if os.path.isdir(os.path.join(path, f))]
        self.files = ["./list.json"]
        self.pluginlist = []
        langs = ["./language/" + self.enable_lang]
        for i in files_dir:
            if os.path.isfile("./plugins/" + i + "/list.json") and os.path.isfile("./plugins/" + i + "/setup.json") \
                    and os.path.isfile("./plugins/" + i + "/__init__.py"):
                setupf = open("./plugins/" + i + "/setup.json")
                setupd = json.load(setupf)
                if "name" in setupd and "version" in setupd and "author" in setupd and "author_email" in setupd and \
                        "description" in setupd:
                    self.files.append("./plugins/" + i + "/list.json")
                    self.pluginlist.append("./plugins/" + i)
                    langs.append("./plugins/" + i + "/language/" + self.enable_lang)

        self.ld = ""
        for i in langs:
            if os.path.isfile(i):
                file = open(i)
                self.ld += file.read() + "\n\n"

    def lang(self, text):
        split = self.ld.split("\n")
        after = []
        for t in text.split("\n"):
            # print(t)
            # print(t,split)
            if t != "":
                if t in split:
                    after.append(split[split.index(t) + 1])
                else:
                    after.append(t)
            else:
                after.append("")
        return "\n".join(after)



import subprocess

import matplotlib.pyplot as plt
import numpy as np
import pandas as pd


def plot_socre(filename, module):
    data = module.Open("./config/config.conf")
    path = data.read().split(",")[9]
    data.close()
    data = pd.read_csv(path + "/" + filename, sep=',', header=None,
                       names=('date', 'team1', 'team2', 'team1_score', 'team2_score', 'toku1', "toku2"),
                       index_col=0)
    heikin = data.mean()
    x = np.array(range(max(max(data["team1_score"]), max(data["team2_score"])) + 1))
    y = np.array([0] * (max(max(data["team1_score"]), max(data["team2_score"])) + 1))
    for i in data["team1_score"]:
        y[i] += 1
    plt.bar(x - 0.15, y, color="y", width=0.3,
            label=data["team1"].values[0] + "\nAverage:" + str(np.round(heikin["team1_score"], decimals=2)))

    x = np.array(range(max(max(data["team1_score"]), max(data["team2_score"])) + 1))
    y = np.array([0] * (max(max(data["team1_score"]), max(data["team2_score"])) + 1))
    for i in data["team2_score"]:
        y[i] += 1
    plt.bar(x + 0.15, y, color="r", width=0.3,
            label=data["team2"].values[0] + "\nAverage:" + str(np.round(heikin["team2_score"], decimals=2)))
    plt.ylabel("number of times")
    plt.xlabel("point")
    plt.legend(loc='best')
    plt.grid(True)
    plt.savefig("file1.png", dpi=300)
    plt.clf()

    csv = open(path + "/" + filename)
    csv2 = open("html.csv", "w")
    csvd = csv.read().splitlines()[1:]
    csvtd = []
    for i in csvd:
        csvtd.append(i.split(","))
    csvd = ""
    for i in csvtd:
        for j in range(len(i)):
            if j != 0:
                if j != len(i)-1:
                    csvd += i[j]+","
                else:
                    csvd += i[j] + "\n"
    csv2.write("プレイヤー1,プレイヤー２," + data["team1"][0] + "の得点," + data["team2"][0] + "の得点," + data["team1"][0] + "の得失点差," +
               data["team2"][0] + "の得失点差\n" + csvd)
    csv.close()
    csv2.close()
    # print(filename)
    return filename


def logs(time):
    subprocess.check_call("mkdir ./html_logs/" + time, shell=True)
    subprocess.check_call("mv ./html.csv ./html_logs/" + time + "/", shell=True)
    subprocess.check_call("mv ./file1.png ./html_logs/" + time + "/", shell=True)
    subprocess.check_call("cp ./index.html ./html_logs/" + time + "/", shell=True)



import os
import subprocess
import time
from datetime import datetime

import cuitools as subp
import tqdm
from texttable import *

from cszp import cszp_html, cszp_log


def loop(cmd, loops, lang, module):
    subp.reset()
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":
        inp = subp.Input(lang.lang("プログラムログを保存しますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    i1 = inp.lower()
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":
        inp = subp.Input(lang.lang("サーバーログを保存しますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    i2 = inp.lower()
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":
        inp = subp.Input(lang.lang("試合の結果をcsvファイルに保存しますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    i3 = inp.lower()
    if i3 == "y":
        file = subp.Input("FileName?")
        subprocess.Popen("python3 -m http.server 20000".split(" "))
        time.sleep(1)
        serverpid = \
            subprocess.check_output("ps o pid,cmd | grep -E 'python3.*http.*20000' | grep -v grep", shell=True).decode(
                "utf-8").split(" ")
        i = 0
        while serverpid[i] == "":
            i += 1
        serverpid = serverpid[i]
        temp = open("html.csv", "w")
        temp.write("ただいま、情報を収集中です。しばらくお待ちください。")
        temp.close()
        subprocess.check_call("cp ./nofile.png ./file1.png", shell=True)
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":
        inp = subp.Input(lang.lang("synch_modeで試合をしますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    i4 = inp.lower()
    if i4 == "y":
        cmd[2] = cmd[2] + " server::synch_mode=true"
    subp.reset()
    print("\033[1m\033[38;5;172m---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------")
    print("\033[38;5;2mTeam1-CMD : bash " + cmd[0])
    print("Team2-CMD : bash " + cmd[1])
    sc = "rcssserver " + cmd[2]
    wc = "soccerwindow2 > /dev/null 2>&1"
    print("\033[38;5;2mSERVER-CMD : " + sc)
    print("WINDOW-CMD : " + wc + "\033[0m")
    tqdmd = tqdm.tqdm(range(loops))

    for _ in tqdmd:
        logs = ""
        logt1 = ""
        logt2 = ""
        logs += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
        logt1 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
        logt2 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"

        try:
            while len(subprocess.check_output("pidof rcssserver", shell=True).decode("utf-8").split()) != 0:
                subprocess.check_output("killall rcssserver", shell=True)
        except subprocess.CalledProcessError:
            pass
        try:
            while len(subprocess.check_output("pidof soccerwindow2-qt4", shell=True).decode("utf-8").split()) != 0:
                subprocess.check_output("killall soccerwindow2-qt4", shell=True)
        except subprocess.CalledProcessError:
            pass
        logs += "SERVER-CMD : " + sc + "\n"

        data = module.Open("./config/config.conf")
        datas = data.read()
        data.close()
        datas = datas.split(",")

        if datas[1] == "on":
            try:
                subprocess.Popen(wc, shell=True)
            except subprocess.CalledProcessError:
                print("\033[38;5;9m\033[1mERR:SOCCERWINDOW2_ERROR")

        try:
            logtemp1 = subprocess.Popen(sc, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            logtemp2 = subprocess.Popen("bash " + cmd[0], shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            time.sleep(1)
            logtemp3 = subprocess.Popen("bash " + cmd[1], shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            stdout, stderr = logtemp1.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            logs += stdout + stderr
            logs += "\n"
            stdout, stderr = logtemp2.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            logt1 += stdout + stderr
            logt1 += "\n"
            stdout, stderr = logtemp3.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            logt2 += stdout + stderr
            logt2 += "\n"
        except subprocess.CalledProcessError or KeyboardInterrupt:
            print("\033[38;5;9m\033[1mERR:RCSSSERVER_ERROR")
            import traceback
            traceback.print_exc()
            subp.Input("press Enter Key")
            return "error"

        logs += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
        logt1 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
        logt2 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
        exittime = datetime.now().strftime("%Y%m%d_%H%M%S")
        try:
            while len(subprocess.check_output("pidof soccerwindow2-qt4", shell=True).decode("utf-8").split()) != 0:
                subprocess.check_output("killall soccerwindow2-qt4", shell=True)
        except subprocess.CalledProcessError:
            pass
        if i1 == "y":
            data = module.Open("./config/config.conf")
            df = data.read()
            # print(df.split("'"))
            temp = open(df.split(",")[9] + "/" + exittime + "_team1.log", "w")
            temp.write(logt1)
            temp.close()
            temp = open(df.split(",")[9] + "/" + exittime + "_team2.log", "w")
            temp.write(logt2)
            temp.close()
        if i2 == "y":
            data = module.Open("./config/config.conf")
            df = data.read()
            # print(df)
            temp = open(df.split(",")[9] + "/" + exittime + "_server.log", "w")
            temp.write(logs)
            temp.close()
        if i3 == "y":
            data = module.Open("./config/config.conf")
            df = data.read()
            # print(df.split(",")[9] + "/" + file)
            temp = open(df.split(",")[9] + "/" + file, "a")
            soccer = cszp_log.log(logs)
            temp.write(
                "\n" + exittime + "," + soccer[0] + "," + soccer[1] + "," + soccer[2] + "," + soccer[3] + "," + str(
                    int(soccer[2]) - int(soccer[3])) + "," + str(int(soccer[3]) - int(soccer[2])))
            temp.close()
            cszp_html.plot_socre(file, module)

            data = module.Open("./config/config.conf")
            path = data.read().split(",")[9]
            data.close()
            temp = open(path + "/data.csv", "a")
            soccer = cszp_log.log(logs)
            temp.write(
                "\n" + exittime + "," + soccer[0] + "," + soccer[1] + "," + soccer[2] + "," + soccer[3] + "," + str(
                    int(soccer[2]) - int(soccer[3])) + "," + str(int(soccer[3]) - int(soccer[2])))
            temp.close()

    print("\033[1m\033[38;5;172m---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------")
    # print(serverpid)
    if i3 == "y":
        subprocess.check_output("kill " + serverpid, shell=True)
        # time.sleep(2)
        cszp_html.logs(exittime)
    subp.Input(lang.lang("Enterキーを押して続行..."))


def start(cmd, lang, module):
    subp.reset()
    logs = ""
    logt1 = ""
    logt2 = ""
    logs += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
    logt1 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
    logt2 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
    print("\033[1m\033[38;5;172m---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------")
    print("\033[38;5;2mTeam1-CMD : bash " + cmd[0])
    print("Team2-CMD : bash " + cmd[1])
    sc = "rcssserver " + cmd[2]
    wc = "soccerwindow2"

    try:
        while len(subprocess.check_output("pidof rcssserver", shell=True).decode("utf-8").split()) != 0:
            subprocess.check_output("killall rcssserver", shell=True)
    except subprocess.CalledProcessError:
        pass
    try:
        while len(subprocess.check_output("pidof soccerwindow2-qt4", shell=True).decode("utf-8").split()) != 0:
            subprocess.check_output("killall soccerwindow2-qt4", shell=True)
    except subprocess.CalledProcessError:
        pass
    logs += "SERVER-CMD : " + sc + "\n"
    print("\033[38;5;2mSERVER-CMD : " + sc)
    print("WINDOW-CMD : " + wc + "\033[0m")

    data = module.Open("./config/config.conf")
    datas = data.read()
    data.close()
    datas = datas.split(",")
    if datas[3] == "on":
        makelog = "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
        makelog += "TEAM1-CONFIGURE-CMD : " + "cd " + os.path.dirname(cmd[0]) + " && ./configure\n"
        makelog += "TEAM1-MAKE-CMD : " + "cd " + os.path.dirname(cmd[0]) + " && make\n"
        makelog += "TEAM2-CONFIGURE-CMD : " + "cd " + os.path.dirname(cmd[1]) + " && ./configure\n"
        makelog += "TEAM2-MAKE-CMD : " + "cd " + os.path.dirname(cmd[1]) + " && make\033[0m\n"
        print("\033[1m\033[38;5;2mTEAM1-CONFIGURE-CMD : " + "cd " + os.path.dirname(cmd[0]) + " && ./configure\n")
        print("TEAM1-MAKE-CMD : " + "cd " + os.path.dirname(cmd[0]) + " && make\n")
        print("TEAM2-CONFIGURE-CMD : " + "cd " + os.path.dirname(cmd[1]) + " && ./configure\n")
        print("TEAM2-MAKE-CMD : " + "cd " + os.path.dirname(cmd[1]) + " && make\033[0m")
        with tqdm.tqdm(total=100) as pbar:
            pbar.set_description("team1-configure")
            logtemp = subprocess.Popen("cd " + os.path.dirname(cmd[0]) + " && ./configure", shell=True,
                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            stdout, stderr = logtemp.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            makelog += stdout + stderr
            makelog += "\n\n"
            pbar.update(25)

            pbar.set_description("team1-make")
            logtemp = subprocess.Popen("cd " + os.path.dirname(cmd[0]) + " && make", shell=True,
                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            stdout, stderr = logtemp.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            makelog += stdout + stderr
            makelog += "\n\n"
            pbar.update(25)

            pbar.set_description("team2-configure")
            logtemp = subprocess.Popen("cd " + os.path.dirname(cmd[1]) + " && ./configure", shell=True,
                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            stdout, stderr = logtemp.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            makelog += stdout + stderr
            makelog += "\n\n"
            pbar.update(25)

            pbar.set_description("team2-make")
            logtemp = subprocess.Popen("cd " + os.path.dirname(cmd[1]) + " && make", shell=True,
                                       stdout=subprocess.PIPE, stderr=subprocess.PIPE)
            stdout, stderr = logtemp.communicate()
            stderr = stderr.decode("utf-8")
            stdout = stdout.decode("utf-8")
            makelog += stdout + stderr
            makelog += "\n\n"
            pbar.update(25)
            makelog += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"

    if datas[1] == "on":
        try:
            subprocess.Popen(wc, shell=True)
        except subprocess.CalledProcessError:
            print("\033[38;5;9m\033[1mERR:SOCCERWINDOW2_ERROR")

    try:
        logtemp1 = subprocess.Popen(sc, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        logtemp2 = subprocess.Popen("bash " + cmd[0], shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        time.sleep(1)
        logtemp3 = subprocess.Popen("bash " + cmd[1], shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        stdout, stderr = logtemp1.communicate()
        stderr = stderr.decode("utf-8")
        stdout = stdout.decode("utf-8")
        logs += stdout + stderr
        logs += "\n"
        stdout, stderr = logtemp2.communicate()
        stderr = stderr.decode("utf-8")
        stdout = stdout.decode("utf-8")
        logt1 += stdout + stderr
        logt1 += "\n"
        stdout, stderr = logtemp3.communicate()
        stderr = stderr.decode("utf-8")
        stdout = stdout.decode("utf-8")
        logt2 += stdout + stderr
        logt2 += "\n"
    except KeyboardInterrupt:
        print("\033[38;5;9m\033[1mERR:RCSSSERVER_ERROR")
        return "error"

    logs += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
    logt1 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
    logt2 += "---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------\n"
    exittime = datetime.now().strftime("%Y%m%d_%H%M%S")
    print("\033[1m\033[38;5;172m---------- " + datetime.now().strftime("%Y/%m/%d %H:%M:%S") + " -----------")
    try:
        while len(subprocess.check_output("pidof soccerwindow2-qt4", shell=True).decode("utf-8").split()) != 0:
            subprocess.check_output("killall soccerwindow2-qt4", shell=True)
    except subprocess.CalledProcessError:
        pass
    soccer = cszp_log.log(logs)
    print(soccer[0] + " " + soccer[2] + " - " + soccer[3] + " " + soccer[1] + " " + cszp_log.kekka(logs, 0, module))
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":
        inp = subp.Input(lang.lang("プログラムログを保存しますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    if inp.lower() == "y":
        data = module.Open("./config/config.conf")
        df = data.read()
        temp = open(df.split(",")[9] + "/" + exittime + "_team1.log", "w")
        temp.write(logt1)
        temp.close()
        temp = open(df.split(",")[9] + "/" + exittime + "_team2.log", "w")
        temp.write(logt2)
        temp.close()
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":
        inp = subp.Input(lang.lang("サーバーログを保存しますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    if inp.lower() == "y":
        data = module.Open("./config/config.conf")
        df = data.read()
        temp = open(df.split(",")[9] + "/" + exittime + "_server.log", "w")
        temp.write(logs)
        temp.close()
    inp = ""
    while inp.lower() != "y" and inp.lower() != "n":

        inp = subp.Input(lang.lang("試合の結果をcsvファイルに保存しますか？ Y/n"))
        if inp.lower() != "y" and inp.lower() != "n":
            print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
    if inp.lower() == "y":
        inp = subp.Input("FileName?")
        data = module.Open("./config/config.conf")
        df = data.read()
        data.close()
        temp = open(df.split(",")[9] + "/" + inp, "a")
        soccer = cszp_log.log(logs)
        temp.write(
            "\n" + exittime + "," + soccer[0] + "," + soccer[1] + "," + soccer[2] + "," + soccer[3] + "," + str(
                int(soccer[2]) - int(soccer[3])) + "," + str(int(soccer[3]) - int(soccer[2])))
        temp.close()

    data = module.Open("./config/config.conf")
    path = data.read().split(",")[9]
    data.close()
    temp = open(path + "/data.csv", "a")
    soccer = cszp_log.log(logs)
    temp.write(
        "\n" + exittime + "," + soccer[0] + "," + soccer[1] + "," + soccer[2] + "," + soccer[3] + "," + str(
            int(soccer[2]) - int(soccer[3])) + "," + str(int(soccer[3]) - int(soccer[2])))
    temp.close()

    inp = ""
    if datas[3] == "on":
        while inp.lower() != "y" and inp.lower() != "n":
            inp = subp.Input(lang.lang("makeログを保存しますか? Y/n"))
            if inp.lower() != "y" and inp.lower() != "n":
                print("\033[1m\033[38;5;9mERR:\033[0m" + lang.lang("yまたはnで答えてください"))
        if inp.lower() == "y":
            data = module.Open("./config/config.conf")
            df = data.read()
            data.close()
            temp = open(df.split(",")[9] + "/" + exittime + "_makelog.log", "w")
            temp.write(makelog)
            temp.close()


def setting(lang, module, testmode=False, loopmode=False):
    ok = 0
    cmd = []

    subp.reset()
    print("\033[0m\033[38;5;172m")
    v = open("./version")
    subprocess.check_call("figlet -ctk cszp " + v.read(), shell=True)
    v.close()
    print("\n\n\033[1m\033[38;5;10m" + lang.lang("cszp 簡単サッカー実行プログラム"))
    print("\033[38;5;39m" + lang.lang("設定確認"))
    # noinspection PyBroadException
    data = module.Open("./config/config.conf")
    datas = data.read()
    data.close()
    datas = datas.split(",")
    datal = []
    for i in range(0, len(datas), 2):
        datat = []
        datat += datas[i:i + 2]
        datal.append(datat)
    table = Texttable()
    table.add_rows(datal)
    print(table.draw())
    subp.Input("Press Enter Key")

    subp.reset()
    while ok == 0:
        subprocess.check_call("clear", shell=True)

        # noinspection PyBroadException
        data = module.Open("./config/setting.conf")
        datas = data.read()
        data.close()
        datas = datas.split(",")
        datal = []
        for i in range(0, len(datas), 2):
            datat = []
            datat += datas[i:i + 2]
            datal.append(datat)
        table = Texttable()
        table.add_rows(datal)
        # inp = subp.Inputfile(lang.lang("\nTeam1(黄色)チームのパスまたはリストの名前を入力"), textcolor="\033[38;5;11m")
        print("\033[0m")
        inp = subp.Inputfilegui(lang.lang("Team1(黄色)チームのパスを入力(リストの名前を入力したい場合はQキー)"))
        if inp == -1:
            print("\033[0m\033[38;5;172m")
            v = open("./version")
            subprocess.check_call("figlet -ctk cszp " + v.read(), shell=True)
            v.close()
            print("\n\n\033[1m\033[38;5;10mcszp " + lang.lang("cszp 簡単サッカー実行プログラム"))
            print("\n\033[38;5;39m" + lang.lang("簡単サッカー実行リスト"))
            print(table.draw() + lang.lang("\n前画面に戻る場合はbackと入力\n"))
            inp = subp.Input(lang.lang("\nTeam1(黄色)チームのリストの名前を入力"), textcolor="\033[38;5;11m")
        if inp == -2:
            raise KeyboardInterrupt

        if inp != "back":
            i = 0
            try:
                while datas[i] != inp:
                    i += 2
                if i < 2:
                    raise IndexError("data_ERROR")
                i += 1
                inp = datas[i]
                # print(inp)
                ok = 1
            except IndexError:
                if os.path.isfile(inp):
                    ok = 1
                else:
                    print("\033[38;5;9m" + lang.lang("ERR:名前"), inp,
                          lang.lang("は簡単サッカー実行リストに登録されていません。\nまた、そのようなファイルも存在しません。\nタイプミスを確認してください"))
                    subp.Input(lang.lang("Enterキーを押して続行..."), dot=False)
        else:
            ok = 2

    cmd.append(inp)
    # print(type(inp))
    # subp.Input("")
    if ok != 2:
        ok = 0
    subp.reset()
    while ok == 0 and ok != 2:
        subprocess.check_call("clear", shell=True)

        # noinspection PyBroadException
        data = module.Open("./config/setting.conf")
        datas = data.read()
        data.close()
        datas = datas.split(",")
        datal = []
        for i in range(0, len(datas), 2):
            datat = []
            datat += datas[i:i + 2]
            datal.append(datat)
        table = Texttable()
        table.add_rows(datal)
        # inp = subp.Inputfile(lang.lang("\nTeam2(赤色)チームのパスまたはリストの名前を入力"), textcolor="\033[38;5;9m")
        print("\033[0m")
        inp = subp.Inputfilegui(lang.lang("Team2(赤色)チームのパスを入力(リストの名前を入力したい場合はQキー)"))
        if inp == -1:
            print("\033[0m\033[38;5;172m")
            v = open("./version")
            subprocess.check_call("figlet -ctk cszp " + v.read(), shell=True)
            v.close()
            print("\n\n\033[1m\033[38;5;10mcszp " + lang.lang("cszp 簡単サッカー実行プログラム"))
            print("\n\033[38;5;39m" + lang.lang("簡単サッカー実行リスト"))
            print(
                table.draw() + lang.lang("\n前画面に戻る場合はbackと入力") + "\n\033[38;5;11m" + lang.lang("Team1(黄色)チームのパス:") +
                cmd[0])
            inp = subp.Input(lang.lang("\nTeam2(赤色)チームのリストの名前を入力"), textcolor="\033[38;5;9m")
        if inp == -2:
            raise KeyboardInterrupt

        if inp != "back":
            i = 0
            try:
                while datas[i] != inp:
                    i += 2
                if i < 2:
                    raise IndexError("data_ERROR")
                i += 1
                inp = datas[i]
                ok = 1
            except IndexError:
                if os.path.isfile(inp):
                    ok = 1
                else:
                    print("\033[38;5;9m" + lang.lang("ERR:名前"), inp,
                          lang.lang("は簡単サッカー実行リストに登録されていません。\nまた、そのようなファイルも存在しません。\nタイプミスを確認してください"))
                    subp.Input("Enterキーを押して続行...", dot=False)
        else:
            ok = 2

    if ok != 2:
        cmd.append(inp)
        subp.reset()
        print("\033[0m\033[38;5;172m")
        v = open("./version")
        subprocess.check_call("figlet -ctk cszp " + v.read(), shell=True)
        v.close()
        print("\n\n\033[1m\033[38;5;10m" + lang.lang("cszp 簡単サッカー実行プログラム"))
        print("\n\033[38;5;11m" + lang.lang("Team1(黄色)チームのパス:") + cmd[0])
        print("\033[38;5;9m" + lang.lang("Team2(赤色)チームのパス:") + cmd[1])
        inp = subp.Input(lang.lang("\nサーバーの引数を入力（ない場合は空欄）"), textcolor="\033[38;5;9m")
        data = module.Open("./config/config.conf")
        df = data.read()
        data.close()
        inp += " server::auto_mode=true server::kick_off_wait=10 server::game_over_wait=10 server::connect_wait=1500 " \
               "server::game_log_dir=" + \
               df.split(",")[9] + " server::text_log_dir=" + df.split(",")[9]
        if testmode:
            inp += " server::nr_normal_halfs=1 server::nr_extra_halfs=0 server::penalty_shoot_outs=0 " \
                   "server::half_time=10"
        if loopmode:
            loops = 0
            while loops == 0:
                try:
                    loops = int(subp.Input("\n" + lang.lang("試合数を指定"), textcolor="\033[38;5;9m"))
                except ValueError:
                    print("\033[38;5;9m" + lang.lang("ERR:数字を入力してください"))

        data = module.Open("./config/config.conf")
        datas = data.read()
        datas = datas.split(",")
        data.close()
        if datas[5] == "off":
            inp += " server::game_logging=false"
        if datas[7] == "off":
            inp += " server::text_logging=false"
        cmd.append(inp)
        print("\n\033[38;5;14mloading now...")
        time.sleep(0.5)
        if loopmode:
            loop(cmd, loops, lang, module)
        else:
            start(cmd, lang, module)



import json

import cuitools


def plugin_text(lang, text):
    return list(map(lambda n: json.load(open(n + "/setup.json"))[text], lang.pluginlist))


def plugin(lang):
    print("\033[0m")
    select = cuitools.printlist("select plugin", plugin_text(lang, "name"))
    if select != -1:
        sselect = 0
        while True:

            printtext = [
                lang.lang("名前:") + plugin_text(lang, "name")[select],
                lang.lang("バージョン:") + plugin_text(lang, "version")[select],
                lang.lang("管理者:") + plugin_text(lang, "author")[select],
                lang.lang("管理者のメールアドレス:") + plugin_text(lang, "author_email")[select],
                ""
            ]
            if sselect == 0:
                printtext.append(">> " + lang.lang("前ページへ戻る(ホーム)"))
                printtext.append("   " + lang.lang("説明を読む"))
            else:
                printtext.append("   " + lang.lang("前ページへ戻る(ホーム)"))
                printtext.append(">> " + lang.lang("説明を読む"))
            # print(printtext)
            cuitools.box(lang.lang("詳細情報") + " " + plugin_text(lang, "name")[select], printtext)
            k = cuitools.Key()
            if k == "\x1b":
                cuitools.Key()
                k = cuitools.Key()
                if k == "B":
                    if sselect < 1:
                        sselect += 1
                elif k == "A":
                    if sselect > 0:
                        sselect -= 1
            elif k == "\n":
                if sselect == 0:
                    break
                else:
                    cuitools.printlist(lang.lang("説明を読む"), plugin_text(lang, "description")[select].splitlines(), False)



import importlib
import json
import locale
import os
import platform
import shutil
import subprocess
import sys
import time

sys.path.append(os.getcwd())
os.chdir(os.path.abspath(os.path.dirname(__file__)))
from cszp.cszp_module import Open, terminal

# sys.path.append(os.path.abspath(os.path.dirname(__file__)))


module = Open()
try:
    from texttable import *
except ModuleNotFoundError:
    v = open("./version")
    print("\033[2Jcszp " + v.read())
    v.close()
    print(
        "\033[1mERR:\033[0mtexttable package is not installed.\ncszp (easy soccer run program) requires texttable.\n"
        "Execute the following command and try again.\n\033[38;5;11mpip3 install texttable"
    )
    sys.exit()

try:
    import cuitools as subp
except ModuleNotFoundError:
    v = open("./version")
    print("\033[2Jcszp " + v.read())
    v.close()
    print(
        "\033[1mERR:\033[0mcuitools package is not installed.\ncszp (easy soccer run program) requires cuitools.\n"
        "Execute the following command and try again.\n\033[38;5;11mpip3 install cuitools"
    )
    sys.exit()

try:
    import tqdm
except ModuleNotFoundError:
    v = open("./version")
    print("\033[2Jcszp " + v.read())
    v.close()
    print(
        "\033[1mERR:\033[0mtqdm package is not installed.\ncszp (easy soccer run program) requires tqdm.\n"
        "Execute the following command and try again.\n\033[38;5;11mpip3 install tqdm"
    )
    sys.exit()

try:
    import matplotlib
except ModuleNotFoundError:
    v = open("./version")
    print("\033[2Jcszp " + v.read())
    v.close()
    print(
        "\033[1mERR:\033[0mmatplotlib package is not installed.\ncszp (easy soccer run program) requires matplotlib.\n"
        "Execute the following command and try again.\n\033[38;5;11mpip3 install matplotlib"
    )
    sys.exit()

try:
    import pandas
except ModuleNotFoundError:
    v = open("./version")
    print("\033[2Jcszp " + v.read())
    v.close()
    print(
        "\033[1mERR:\033[0mpandas package is not installed.\ncszp (easy soccer run program) requires pandas.\n"
        "Execute the following command and try again.\n\033[38;5;11mpip3 install pandas"
    )
    sys.exit()


def main():
    # noinspection PyBroadException
    try:
        subp.reset()
        print("\033[0m\033[38;5;172m")
        ver = open("./version")
        subprocess.check_call("figlet -ctk cszp " + ver.read(), shell=True)
        ver.close()
    except Exception:
        ver = open("./version")
        print("\033[2Jcszp " + ver.read())
        ver.close()
        print(
            "\033[1mERR:\033[0mfiglet package is not installed.\ncszp (easy soccer run program) requires figlet."
            "\nExecute the following command and try again.\n\033[38;5;11msudo apt install figlet "
        )
        sys.exit()
    time.sleep(1)

    print("")
    if int(sys.version_info[0]) == 3 and int(sys.version_info[1]) > 2:
        sys.stdout.write("\033[38;5;10m\033[1m[OK] ")
        print("\033[0m\033[38;5;2mpythonVersion\033[38;5;7m:\033[38;5;6m" + platform.python_version())
        time.sleep(0.2)
        print("\033[38;5;2mloading Now...")
        time.sleep(0.5)
    else:
        sys.stdout.write("\033[38;5;9m\033[1m[FAILD] ")
        print("\033[0m\033[38;5;2mpythonVersion\033[38;5;7m:\033[38;5;6m" + platform.python_version())
        print("\033[38;5;9m\033[1mERR:\033[0mThis program requires python3.2 or higher version.")
        sys.exit()

    if not os.path.isdir("config"):
        print("\033[38;5;4m[INFO]\033[0mCreate directory: config")
        os.mkdir("config")
    data = module.Open("./config/config.conf")
    path = data.read().split(",")[9]
    data.close()
    if not os.path.isdir("html_logs"):
        print("\033[38;5;4m[INFO]\033[0mCreate directory: html_logs")
        os.mkdir("html_logs")
    if not os.path.isdir(path):
        print("\033[38;5;4m[INFO]\033[0mCreate directory: csvdata")
        os.mkdir(path)
    if not os.path.isfile(path + "/data.csv"):
        print("\033[38;5;4m[INFO]\033[0mCreate file: data.csv")
        temp = open(path + "/data.csv", "w")
        temp.close()
    if not os.path.isdir("plugins"):
        print("\033[38;5;4m[INFO]\033[0mCreate directory: plugins")
        os.mkdir("plugins")

    # main
    from cszp import cszp_menu

    if not os.path.isfile("lang"):
        file = open("lang.json")
        lang_list = json.load(file)
        file.close()
        langf = open("lang", "w")
        langn = [k for k, n in lang_list.items() if n == locale.getlocale()[0].lower() + ".lang"]
        if len(langn) == 1:
            langf.write(langn[0])
        else:
            langf.write("1")
        langf.close()
    lang = terminal()
    try:
        r = cszp_menu.menu(lang, module)
    except KeyboardInterrupt:
        r = 0
    except EOFError:
        r = 0
    except Exception:
        r = 0
        import traceback
        temp = "CSZP PROGRAM ERROR\ncszp=" + open("version").read() + "\n"
        file = open("./errorlog.log", "w")
        temp += "---------- error log ----------\n" + traceback.format_exc() + "\n"
        temp += "---------- computer information ----------\nwhich python3 : " + shutil.which(
            'python3') + "\n" + "\n".join(map(lambda n: "=".join(n), list(os.environ.items())))
        temp += "\n\n---------- file list ----------\n" + subprocess.check_output("ls -al", shell=True).decode("utf-8")
        file.write(temp)
        file.close()
        print("\033[0m")
        subp.box(lang.lang("エラー"),
                 [temp.splitlines()[0], lang.lang("ログを確認してください"), "", os.getcwd() + "/errorlog.log", "",
                  lang.lang("Enterキーを押して続行...")])
        k = ""
        while k != "\n":
            k = subp.Key()

    #  stop
    subp.reset()
    print("\033[0m\033[38;5;172m")
    ver = open("./version")
    subprocess.check_call("figlet -ctk cszp " + ver.read(), shell=True)
    ver.close()
    sys.stdout.write("\033[38;5;10m\033[1m[OK] ")
    print("\033[0m\033[38;5;2mpythonVersion\033[38;5;7m:\033[38;5;6m" + platform.python_version())
    print("\033[38;5;2mloading Now...")
    print("\n\n\033[38;5;2mloading Now...")
    time.sleep(0.5)
    print("stoped.")
    time.sleep(0.25)
    subp.reset()
    if r == 2 or r == 3:
        importlib.reload(cszp_menu)
        main()


if __name__ == '__main__':
    main()



def log(data):
    logdata = data.find("vs")
    while data[logdata] != "\t":
        logdata -= 1
    team1s = logdata + 2

    logdata += 2
    while data[logdata] != "'":
        logdata += 1
    team1e = logdata

    logdata += 1
    while data[logdata] != "'":
        logdata += 1
    team2s = logdata + 1

    logdata += 1
    while data[logdata] != "'":
        logdata += 1
    team2e = logdata

    team1n = data[team1s:team1e]
    team2n = data[team2s:team2e]

    while data[logdata] != " ":
        logdata += 1

    logdata += 1
    team1s = logdata

    while data[logdata] != " ":
        logdata += 1

    team1e = logdata
    logdata += 1

    while data[logdata] != " ":
        logdata += 1

    logdata += 1
    team2s = logdata

    while data[logdata] != "\n":
        logdata += 1

    team2e = logdata

    team1p = data[team1s:team1e]
    team2p = data[team2s:team2e]
    return team1n, team2n, team1p, team2p


def kekka(logs, lang, module):
    data = module.Open("./config/config.conf")
    path = data.read().split(",")[9]
    data.close()
    csvf = open(path + "/data.csv")
    csv = csvf.read()
    csv = csv.split("\n")
    k = log(logs)
    i = len(csv) - 1
    if k[2] == k[3]:
        if lang == 0:
            return "同点！今後が楽しみです！"
        else:
            return "Draw!We look forward to the future!"
    if max(int(k[2]), int(k[3])) == int(k[2]):
        ka = 0
    else:
        ka = 1

    re = 0
    rp = 0
    hit = 0
    while i >= 0:
        # print(i)
        temp = csv[i].split(",")
        # print(temp)
        if len(temp) == 1:
            pass
        elif temp[0] == k[ka]:
            hit += 1
            if int(temp[2]) == int(temp[3]):
                break
            elif max(int(temp[2]), int(temp[3])) == int(temp[2]):
                re += 1
            else:
                re = 0
                rp += 1
                break

        elif temp[1] == k[ka]:
            hit += 1
            if int(temp[2]) == int(temp[3]):
                break
            elif max(int(temp[2]), int(temp[3])) == int(temp[3]):
                re += 1
            else:
                re = 0
                rp += 1
                break
        i -= 1
    if lang == 0:
        if re == 0:
            if hit != 0:
                return k[ka] + "さんの勝ち！そして、連敗復帰！今後が楽しみです！"
            else:
                return k[ka] + "さんの勝ち！今後が楽しみです！"
        else:
            return k[ka] + "さんの勝ち！そして" + str(re + 1) + "連勝中！"
    else:
        if re == 0:
            if hit != 0:
                return k[ka] + " Won! And return to consecutive losses! We look forward to the future!"
            else:
                return k[ka] + " Won! We look forward to the future!"
        else:
            return k[ka] + " won! And " + str(re + 1) + " consecutive wins!"



import json
import os
import subprocess

import cszp.cszp_lang


def killsoccer():
    try:
        while len(subprocess.check_output("pidof rcssserver", shell=True).decode("utf-8").split()) != 0:
            subprocess.check_output("killall rcssserver", shell=True)
    except subprocess.CalledProcessError:
        pass
    try:
        while len(subprocess.check_output("pidof soccerwindow2-qt4", shell=True).decode("utf-8").split()) != 0:
            subprocess.check_output("killall soccerwindow2-qt4", shell=True)
    except subprocess.CalledProcessError:
        pass
    try:
        while True:
            serverpid = subprocess.check_output("ps o pid,cmd | grep -E 'python3.*http.*20000' | grep -v grep",
                                                shell=True).decode("utf-8").split("\n")[0].split(" ")[0]
            subprocess.check_output("kill " + serverpid, shell=True)
    except subprocess.CalledProcessError:
        pass


class Open:
    def __init__(self):
        self.writelist = {
            "config": "soccerwindow2start,on,automake,off,rcglog output,on,rcllog output,on,logfile output," +
                      os.path.expanduser("~") + "/csvdata",
            "setting": "name,command"
        }

    def Open(self, file):
        if os.path.isfile(file):
            data = open(file, "r")
        else:
            data = open(file, "w")
            data.write(self.writelist[os.path.splitext(os.path.basename(file))[0]])
            data.close()
            data = open(file, "r")
        return data


class terminal(cszp.cszp_lang.lang):
    def question(self, key, note="cszp 簡単サッカー実行プログラム"):
        title = []
        description = []
        for j in self.files:
            listf = open(j)
            listd = json.load(listf)
            listf.close()
            if key in listd:
                for i in listd[key]:
                    title.append(i["title"])
                for i in listd[key]:
                    description.append(self.lang(i["description"]))

        titlemax = len(max(title, key=lambda n: len(n)))
        title = list(map(lambda n: n.ljust(titlemax), title))
        temp = self.lang(note) + "\n\n"
        for i in range(len(title)):
            temp += title[i] + " " * 4 + description[i] + "\n"
        temp += ">>> "
        return temp

    def searchcmd(self, key, text):
        hit = 0
        for j in self.files:

            listf = open(j)
            listd = json.load(listf)
            listf.close()
            if key in listd:
                for i in listd[key]:
                    if i["cmd"] == text.split(" ")[0]:
                        hit = 1
        return hit

    def functo(self, key, text):
        func = None
        path = None
        for j in self.files:
            listf = open(j)
            listd = json.load(listf)
            listf.close()
            if key in listd:
                for i in listd[key]:
                    # print(i["cmd"], text, i["cmd"] == text)
                    if i["cmd"] == text:
                        path = os.path.dirname(j)
                        func = os.path.dirname(j).replace(".", "").replace("/", ".")[1:] + ".__init__"
        return path, func
